@@ -37,7 +37,7 @@
 #include <osmocom/core/timer.h>
 #include <ctype.h>
 
-const static struct rate_ctr_group_desc rate_ctr_group_desc = {
+static const struct rate_ctr_group_desc rate_ctr_group_desc = {
 	.group_name_prefix = "conn_rtp",
 	.group_description = "rtp connection statistics",
 	.class_id = 1,
@@ -95,15 +95,21 @@ static int mgcp_rtp_conn_init(struct mgcp_conn_rtp *conn_rtp, struct mgcp_conn *
 	static atomic_uint rate_ctr_index = 0;
 
 	conn_rtp->type = MGCP_RTP_DEFAULT;
-	conn_rtp->osmux.cid_allocated = false;
-	conn_rtp->osmux.cid = 0;
+
+	/* Osmux specific defaults, only used if conn is later on Osmux-enabled: */
+	conn_rtp->osmux.state = OSMUX_STATE_DISABLED;
+	conn_rtp->osmux.local_cid_allocated = false;
+	conn_rtp->osmux.local_cid = 0;
+	conn_rtp->osmux.remote_cid_present = false;
+	conn_rtp->osmux.remote_cid = 0;
 
 	/* backpointer to the generic part of the connection */
 	conn->u.rtp.conn = conn;
 
 	end->rtp.fd = -1;
 	end->rtcp.fd = -1;
-	end->rtp_port = end->rtcp_port = 0;
+	memset(&end->addr, 0, sizeof(end->addr));
+	end->rtcp_port = 0;
 	talloc_free(end->fmtp_extra);
 	end->fmtp_extra = NULL;
 
@@ -113,12 +119,12 @@ static int mgcp_rtp_conn_init(struct mgcp_conn_rtp *conn_rtp, struct mgcp_conn *
 	end->output_enabled = false;
 	end->maximum_packet_time = -1;
 
-	conn_rtp->rate_ctr_group = rate_ctr_group_alloc(conn, &rate_ctr_group_desc, rate_ctr_index++);
-	if (!conn_rtp->rate_ctr_group)
+	conn_rtp->ctrg = rate_ctr_group_alloc(conn, &rate_ctr_group_desc, rate_ctr_index++);
+	if (!conn_rtp->ctrg)
 		return -1;
 
-	conn_rtp->state.in_stream.err_ts_ctr = rate_ctr_group_get_ctr(conn_rtp->rate_ctr_group, IN_STREAM_ERR_TSTMP_CTR);
-	conn_rtp->state.out_stream.err_ts_ctr = rate_ctr_group_get_ctr(conn_rtp->rate_ctr_group, OUT_STREAM_ERR_TSTMP_CTR);
+	conn_rtp->state.in_stream.err_ts_ctr = rate_ctr_group_get_ctr(conn_rtp->ctrg, IN_STREAM_ERR_TSTMP_CTR);
+	conn_rtp->state.out_stream.err_ts_ctr = rate_ctr_group_get_ctr(conn_rtp->ctrg, OUT_STREAM_ERR_TSTMP_CTR);
 
 	/* Make sure codec table is reset */
 	mgcp_codec_reset_all(conn_rtp);
@@ -134,7 +140,7 @@ static void mgcp_rtp_conn_cleanup(struct mgcp_conn_rtp *conn_rtp)
 	if (mgcp_conn_rtp_is_iuup(conn_rtp))
 		mgcp_conn_iuup_cleanup(conn_rtp);
 	mgcp_free_rtp_port(&conn_rtp->end);
-	rate_ctr_group_free(conn_rtp->rate_ctr_group);
+	rate_ctr_group_free(conn_rtp->ctrg);
 	mgcp_codec_reset_all(conn_rtp);
 }
 
@@ -263,7 +269,7 @@ struct mgcp_conn_rtp *mgcp_conn_get_rtp(struct mgcp_endpoint *endp,
 static void aggregate_rtp_conn_stats(struct mgcp_endpoint *endp, struct mgcp_conn_rtp *conn_rtp)
 {
 	struct rate_ctr_group *all_stats = endp->trunk->ratectr.all_rtp_conn_stats;
-	struct rate_ctr_group *conn_stats = conn_rtp->rate_ctr_group;
+	struct rate_ctr_group *conn_stats = conn_rtp->ctrg;
 
 	if (all_stats == NULL || conn_stats == NULL)
 		return;
@@ -360,14 +366,38 @@ char *mgcp_conn_dump(struct mgcp_conn *conn)
 
 	switch (conn->type) {
 	case MGCP_CONN_TYPE_RTP:
-		/* Dump RTP connection */
-		snprintf(str, sizeof(str), "(%s/rtp, id:0x%s, ip:%s, "
-			 "rtp:%u rtcp:%u)",
-			 conn->name,
-			 conn->id,
-			 osmo_sockaddr_ntop(&conn->u.rtp.end.addr.u.sa, ipbuf),
-			 ntohs(conn->u.rtp.end.rtp_port),
-			 ntohs(conn->u.rtp.end.rtcp_port));
+		switch (conn->u.rtp.type) {
+		case MGCP_RTP_DEFAULT:
+			/* Dump RTP connection */
+			snprintf(str, sizeof(str), "(%s/rtp, id:0x%s, ip:%s, "
+				"rtp:%u rtcp:%u)",
+				conn->name, conn->id,
+				osmo_sockaddr_ntop(&conn->u.rtp.end.addr.u.sa, ipbuf),
+				osmo_sockaddr_port(&conn->u.rtp.end.addr.u.sa),
+				ntohs(conn->u.rtp.end.rtcp_port));
+			break;
+		case MGCP_RTP_OSMUX:
+			snprintf(str, sizeof(str), "(%s/osmux, id:0x%s, ip:%s, "
+				"port:%u CID:%u)",
+				conn->name, conn->id,
+				osmo_sockaddr_ntop(&conn->u.rtp.end.addr.u.sa, ipbuf),
+				osmo_sockaddr_port(&conn->u.rtp.end.addr.u.sa),
+				conn->u.rtp.osmux.local_cid);
+			break;
+		case MGCP_RTP_IUUP:
+			snprintf(str, sizeof(str), "(%s/iuup, id:0x%s, ip:%s, "
+				"port:%u)",
+				conn->name, conn->id,
+				osmo_sockaddr_ntop(&conn->u.rtp.end.addr.u.sa, ipbuf),
+				osmo_sockaddr_port(&conn->u.rtp.end.addr.u.sa));
+			break;
+		default:
+			/* Should not happen, we should be able to dump
+			 * every possible connection type. */
+			snprintf(str, sizeof(str), "(unknown conn_rtp connection type %u)",
+				 conn->u.rtp.type);
+			break;
+		}
 		break;
 
 	default:
